@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 import numpy as np
-from FADiff import FADiff
+from FADiff.FADiff import FADiff
 # import FADiff
 
 class Vect:
